=== modified file 'client/drizzle.cc'
--- client/drizzle.cc	2011-02-17 00:14:13 +0000
+++ client/drizzle.cc	2011-02-22 00:30:21 +0000
@@ -37,7 +37,8 @@
 #include <config.h>
 #include <libdrizzle/drizzle_client.h>
 
-#include <client/get_password.h>
+#include "server_detect.h"
+#include "get_password.h"
 
 #include <boost/date_time/posix_time/posix_time.hpp>
 
@@ -307,6 +308,7 @@
 static uint32_t select_limit;
 static uint32_t max_join_size;
 static uint32_t opt_connect_timeout= 0;
+static ServerDetect::server_type server_type= ServerDetect::SERVER_UNKNOWN_FOUND;
 std::string current_db,
   delimiter_str,  
   current_host,
@@ -3128,11 +3130,15 @@
   drizzle_return_t ret;
   drizzle_column_st *field;
   std::vector<bool> num_flag;
+  std::vector<bool> boolean_flag;
+  std::vector<bool> ansi_boolean_flag;
   string separator;
 
   separator.reserve(256);
 
   num_flag.resize(drizzle_result_column_count(result));
+  boolean_flag.resize(drizzle_result_column_count(result));
+  ansi_boolean_flag.resize(drizzle_result_column_count(result));
   if (column_types_flag)
   {
     print_field_types(result);
@@ -3175,6 +3181,14 @@
       // Room for "NULL"
       length=4;
     }
+    if ((length < 5) and 
+      (server_type == ServerDetect::SERVER_DRIZZLE_FOUND) and
+      (drizzle_column_type(field) == DRIZZLE_COLUMN_TYPE_TINY) and
+      (drizzle_column_type(field) & DRIZZLE_COLUMN_FLAGS_UNSIGNED))
+    {
+      // Room for "FALSE"
+      length= 5;
+    }
     drizzle_column_set_max_size(field, length);
 
     for (x=0; x< (length+2); x++)
@@ -3198,6 +3212,24 @@
                   drizzle_column_name(field));
       num_flag[off]= ((drizzle_column_type(field) <= DRIZZLE_COLUMN_TYPE_LONGLONG) ||
                       (drizzle_column_type(field) == DRIZZLE_COLUMN_TYPE_NEWDECIMAL));
+      if ((server_type == ServerDetect::SERVER_DRIZZLE_FOUND) and
+        (drizzle_column_type(field) == DRIZZLE_COLUMN_TYPE_TINY))
+      {
+        if ((drizzle_column_flags(field) & DRIZZLE_COLUMN_FLAGS_UNSIGNED))
+        {
+          ansi_boolean_flag[off]= true;
+        }
+        else
+        {
+          ansi_boolean_flag[off]= false;
+        }
+        boolean_flag[off]= true;
+        num_flag[off]= false;
+      }
+      else
+      {
+        boolean_flag[off]= false;
+      }
     }
     (void) tee_fputs("\n", PAGER);
     tee_puts((char*) separator.c_str(), PAGER);
@@ -3236,6 +3268,35 @@
         buffer= "NULL";
         data_length= 4;
       }
+      else if (boolean_flag[off])
+      {
+        if (strncmp(cur[off],"1", 1) == 0)
+        {
+          if (ansi_boolean_flag[off])
+          {
+            buffer= "YES";
+            data_length= 3;
+          }
+          else
+          {
+            buffer= "TRUE";
+            data_length= 4;
+          }
+        }
+        else
+        {
+          if (ansi_boolean_flag[off])
+          {
+            buffer= "NO";
+            data_length= 2;
+          }
+          else
+          {
+            buffer= "FALSE";
+            data_length= 5;
+          }
+        }
+      }
       else
       {
         buffer= cur[off];
@@ -3509,16 +3570,41 @@
   drizzle_return_t ret;
   drizzle_column_st *field;
   size_t *lengths;
-
-  if (opt_silent < 2 && column_names)
+  std::vector<bool> boolean_flag;
+  std::vector<bool> ansi_boolean_flag;
+
+  boolean_flag.resize(drizzle_result_column_count(result));
+  ansi_boolean_flag.resize(drizzle_result_column_count(result));
+
+  int first=0;
+  for (uint32_t off= 0; (field = drizzle_column_next(result)); off++)
   {
-    int first=0;
-    while ((field = drizzle_column_next(result)))
+    if (opt_silent < 2 && column_names)
     {
       if (first++)
         (void) tee_fputs("\t", PAGER);
       (void) tee_fputs(drizzle_column_name(field), PAGER);
     }
+    if ((server_type == ServerDetect::SERVER_DRIZZLE_FOUND) and
+      (drizzle_column_type(field) == DRIZZLE_COLUMN_TYPE_TINY))
+    {
+      if ((drizzle_column_flags(field) & DRIZZLE_COLUMN_FLAGS_UNSIGNED))
+      {
+        ansi_boolean_flag[off]= true;
+      }
+      else
+      {
+        ansi_boolean_flag[off]= false;
+      }
+      boolean_flag[off]= true;
+    }
+    else
+    {
+      boolean_flag[off]= false;
+    }
+  }
+  if (opt_silent < 2 && column_names)
+  {
     (void) tee_fputs("\n", PAGER);
   }
   while (1)
@@ -3539,11 +3625,40 @@
       break;
 
     lengths= drizzle_row_field_sizes(result);
-    safe_put_field(cur[0],lengths[0]);
-    for (uint32_t off=1 ; off < drizzle_result_column_count(result); off++)
+    drizzle_column_seek(result, 0);
+    for (uint32_t off=0 ; off < drizzle_result_column_count(result); off++)
     {
-      (void) tee_fputs("\t", PAGER);
-      safe_put_field(cur[off], lengths[off]);
+      if (off != 0)
+        (void) tee_fputs("\t", PAGER);
+      if (boolean_flag[off])
+      {
+        if (strncmp(cur[off],"1", 1) == 0)
+        {
+          if (ansi_boolean_flag[off])
+          {
+            safe_put_field("YES", 3);
+          }
+          else
+          {
+            safe_put_field("TRUE", 4);
+          }
+        }
+        else
+        {
+          if (ansi_boolean_flag[off])
+          {
+            safe_put_field("NO", 2);
+          }
+          else
+          {
+            safe_put_field("FALSE", 5);
+          }
+        }
+      }
+      else
+      {
+        safe_put_field(cur[off], lengths[off]);
+      }
     }
     (void) tee_fputs("\n", PAGER);
     if (quick)
@@ -4108,6 +4223,9 @@
   }
   connected=1;
 
+  ServerDetect server_detect(&con);
+  server_type= server_detect.getServerType();
+
   build_completion_hash(opt_rehash, 1);
   return 0;
 }

=== modified file 'client/drizzledump.cc'
--- client/drizzledump.cc	2011-02-15 23:05:12 +0000
+++ client/drizzledump.cc	2011-02-21 13:59:06 +0000
@@ -241,9 +241,9 @@
     cout << "-- Host: " << current_host << "    Database: " << db_name << endl;
     cout << "-- ------------------------------------------------------" << endl;
     cout << "-- Server version\t" << db_connection->getServerVersion();
-    if (db_connection->getServerType() == DrizzleDumpConnection::SERVER_MYSQL_FOUND)
+    if (db_connection->getServerType() == ServerDetect::SERVER_MYSQL_FOUND)
       cout << " (MySQL server)";
-    else if (db_connection->getServerType() == DrizzleDumpConnection::SERVER_DRIZZLE_FOUND)
+    else if (db_connection->getServerType() == ServerDetect::SERVER_DRIZZLE_FOUND)
       cout << " (Drizzle server)";
     cout << endl << endl;
   }
@@ -351,7 +351,7 @@
     std::cerr << _("-- Retrieving database structures...") << std::endl;
 
   /* Blocking the MySQL privilege tables too because we can't import them due to bug#646187 */
-  if (db_connection->getServerType() == DrizzleDumpConnection::SERVER_MYSQL_FOUND)
+  if (db_connection->getServerType() == ServerDetect::SERVER_MYSQL_FOUND)
     query= "SELECT SCHEMA_NAME, DEFAULT_COLLATION_NAME FROM INFORMATION_SCHEMA.SCHEMATA WHERE SCHEMA_NAME NOT IN ('information_schema', 'performance_schema', 'mysql')";
   else
     query= "SELECT SCHEMA_NAME, DEFAULT_COLLATION_NAME FROM DATA_DICTIONARY.SCHEMAS WHERE SCHEMA_NAME NOT IN ('information_schema','data_dictionary')";
@@ -360,7 +360,7 @@
   while ((row= drizzle_row_next(tableres)))
   {
     std::string database_name(row[0]);
-    if (db_connection->getServerType() == DrizzleDumpConnection::SERVER_MYSQL_FOUND)
+    if (db_connection->getServerType() == ServerDetect::SERVER_MYSQL_FOUND)
       database= new DrizzleDumpDatabaseMySQL(database_name, db_connection);
     else
       database= new DrizzleDumpDatabaseDrizzle(database_name, db_connection);
@@ -383,7 +383,7 @@
   for (vector<string>::const_iterator it= db_names.begin(); it != db_names.end(); ++it)
   {
     temp= *it;
-    if (db_connection->getServerType() == DrizzleDumpConnection::SERVER_MYSQL_FOUND)
+    if (db_connection->getServerType() == ServerDetect::SERVER_MYSQL_FOUND)
       database= new DrizzleDumpDatabaseMySQL(temp, db_connection);
     else
       database= new DrizzleDumpDatabaseDrizzle(temp, db_connection);
@@ -396,7 +396,7 @@
 {
   DrizzleDumpDatabase *database;
 
-  if (db_connection->getServerType() == DrizzleDumpConnection::SERVER_MYSQL_FOUND)
+  if (db_connection->getServerType() == ServerDetect::SERVER_MYSQL_FOUND)
     database= new DrizzleDumpDatabaseMySQL(db, db_connection);
   else
     database= new DrizzleDumpDatabaseDrizzle(db, db_connection);
@@ -742,7 +742,7 @@
     maybe_exit(EX_DRIZZLEERR);
   }
 
-  if ((db_connection->getServerType() == DrizzleDumpConnection::SERVER_MYSQL_FOUND) and (not opt_data_is_mangled))
+  if ((db_connection->getServerType() == ServerDetect::SERVER_MYSQL_FOUND) and (not opt_data_is_mangled))
     db_connection->queryNoResult("SET NAMES 'utf8'");
 
   if (vm.count("destination-type"))

=== modified file 'client/drizzledump_data.cc'
--- client/drizzledump_data.cc	2010-12-08 07:35:23 +0000
+++ client/drizzledump_data.cc	2011-02-21 14:04:40 +0000
@@ -373,6 +373,13 @@
           {
             os << "NULL";
           }
+          else if (obj.table->fields[i]->type.compare("BOOLEAN") == 0)
+          {
+            if (strncmp(row[i], "1", 1) == 0)
+              os << "TRUE";
+            else
+              os << "FALSE";
+          }
           else
             os << "'" << DrizzleDumpData::escape(row[i], row_sizes[i]) << "'";
           byte_counter+= 3;
@@ -561,19 +568,10 @@
     throw std::exception();
   }
 
-  boost::match_flag_type flags = boost::match_default; 
-
-  boost::regex mysql_regex("(5\\.[0-9]+\\.[0-9]+)");
-  boost::regex drizzle_regex("(20[0-9]{2}\\.(0[1-9]|1[012])\\.[0-9]+)");
-
-  std::string version(getServerVersion());
-
-  if (regex_search(version, mysql_regex, flags))
-    serverType= SERVER_MYSQL_FOUND;
-  else if (regex_search(version, drizzle_regex, flags))
-    serverType= SERVER_DRIZZLE_FOUND;
-  else
-    serverType= SERVER_UNKNOWN_FOUND;
+  ServerDetect server_detect= ServerDetect(&connection);
+
+  serverType= server_detect.getServerType();
+  serverVersion= server_detect.getServerVersion();
 }
 
 drizzle_result_st* DrizzleDumpConnection::query(std::string &str_query)

=== modified file 'client/drizzledump_data.h'
--- client/drizzledump_data.h	2010-12-08 07:35:23 +0000
+++ client/drizzledump_data.h	2011-02-21 13:59:06 +0000
@@ -22,6 +22,7 @@
 
 #define DRIZZLE_MAX_LINE_LENGTH 1024*1024L-1025
 #include "client_priv.h"
+#include "server_detect.h"
 #include <string>
 #include <iostream>
 #include <iomanip>
@@ -214,14 +215,10 @@
     drizzle_con_st connection;
     std::string hostName;
     bool drizzleProtocol;
-    int serverType;
+    ServerDetect::server_type serverType;
+    std::string serverVersion;
 
   public:
-    enum server_type {
-      SERVER_MYSQL_FOUND,
-      SERVER_DRIZZLE_FOUND,
-      SERVER_UNKNOWN_FOUND
-    };
     DrizzleDumpConnection(std::string &host, uint16_t port,
       std::string &username, std::string &password, bool drizzle_protocol);
     ~DrizzleDumpConnection();
@@ -244,7 +241,7 @@
     bool setDB(std::string databaseName);
     bool usingDrizzleProtocol(void) const { return drizzleProtocol; }
     bool getServerType(void) const { return serverType; }
-    const char* getServerVersion(void) { return drizzle_con_server_version(&connection); }
+    std::string getServerVersion(void) const { return serverVersion; }
 };
 
 class DrizzleStringBuf : public std::streambuf

=== modified file 'client/drizzledump_drizzle.cc'
--- client/drizzledump_drizzle.cc	2010-12-06 12:15:06 +0000
+++ client/drizzledump_drizzle.cc	2011-02-20 10:23:17 +0000
@@ -195,9 +195,9 @@
     else
       field->defaultValue= "";
 
-    field->isNull= (strcmp(row[4], "YES") == 0) ? true : false;
-    field->isAutoIncrement= (strcmp(row[9], "YES") == 0) ? true : false;
-    field->defaultIsNull= (strcmp(row[3], "YES") == 0) ? true : false;
+    field->isNull= (boost::lexical_cast<uint32_t>(row[4])) ? true : false;
+    field->isAutoIncrement= (boost::lexical_cast<uint32_t>(row[9])) ? true : false;
+    field->defaultIsNull= (boost::lexical_cast<uint32_t>(row[3])) ? true : false;
     field->enumValues= (row[10]) ? row[10] : "";
     field->length= (row[5]) ? boost::lexical_cast<uint32_t>(row[5]) : 0;
     field->decimalPrecision= (row[6]) ? boost::lexical_cast<uint32_t>(row[6]) : 0;
@@ -244,7 +244,7 @@
         indexes.push_back(index);
       index = new DrizzleDumpIndexDrizzle(indexName, dcon);
       index->isPrimary= (strcmp(row[0], "PRIMARY") == 0);
-      index->isUnique= (strcmp(row[3], "YES") == 0);
+      index->isUnique= boost::lexical_cast<uint32_t>(row[3]);
       index->isHash= 0;
       index->length= (row[4]) ? boost::lexical_cast<uint32_t>(row[4]) : 0;
       lastKey= row[0];

=== modified file 'client/drizzletest.cc'
--- client/drizzletest.cc	2011-02-17 00:14:13 +0000
+++ client/drizzletest.cc	2011-02-21 18:47:31 +0000
@@ -4697,8 +4697,36 @@
     for (i = 0; i < num_fields; i++)
     {
       column= drizzle_column_next(res);
-      append_field(ds, i, column,
-                   (const char*)row[i], lengths[i], !row[i]);
+      if (row[i] && (drizzle_column_type(column) == DRIZZLE_COLUMN_TYPE_TINY))
+      {
+        if (boost::lexical_cast<uint32_t>(row[i]))
+        {
+          if ((drizzle_column_flags(column) & DRIZZLE_COLUMN_FLAGS_UNSIGNED))
+          {
+            append_field(ds, i, column, "YES", 3, false);
+          }
+          else
+          {
+            append_field(ds, i, column, "TRUE", 4, false);
+          }
+        }
+        else
+        {
+          if ((drizzle_column_flags(column) & DRIZZLE_COLUMN_FLAGS_UNSIGNED))
+          {
+            append_field(ds, i, column, "NO", 2, false);
+          }
+          else
+          {
+            append_field(ds, i, column, "FALSE", 5, false);
+          }
+        }
+      }
+      else
+      {
+        append_field(ds, i, column,
+                     (const char*)row[i], lengths[i], !row[i]);
+      }
     }
     if (!display_result_vertically)
       ds->append("\n");
@@ -4742,7 +4770,14 @@
     ds->append("\t", 1);
     replace_append_uint(ds, drizzle_column_size(column));
     ds->append("\t", 1);
-    replace_append_uint(ds, drizzle_column_max_size(column));
+    if (drizzle_column_type(column) == DRIZZLE_COLUMN_TYPE_TINY)
+    {
+      replace_append_uint(ds, 1);
+    }
+    else
+    {
+      replace_append_uint(ds, drizzle_column_max_size(column));
+    }
     ds->append("\t", 1);
     ds->append((char*) ((drizzle_column_flags(column) & DRIZZLE_COLUMN_FLAGS_NOT_NULL) ? "N" : "Y"), 1);
     ds->append("\t", 1);

=== modified file 'client/include.am'
--- client/include.am	2010-12-28 20:54:15 +0000
+++ client/include.am	2011-02-21 13:59:06 +0000
@@ -54,6 +54,7 @@
                  client/drizzledump_drizzle.h \
                  client/drizzledump_mysql.h \
                  client/option_string.h \
+                 client/server_detect.h \
                  client/statement.h \
                  client/stats.h \
                  client/thread_context.h \

=== added file 'client/server_detect.h'
--- client/server_detect.h	1970-01-01 00:00:00 +0000
+++ client/server_detect.h	2011-02-21 13:59:06 +0000
@@ -0,0 +1,61 @@
+/* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2011 Andrew Hutchings
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; version 2 of the License.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#ifndef CLIENT_SERVER_DETECT_H
+#define CLIENT_SERVER_DETECT_H
+
+#include <boost/regex.hpp>
+
+class ServerDetect
+{
+  public:
+    enum server_type {
+      SERVER_MYSQL_FOUND,
+      SERVER_DRIZZLE_FOUND,
+      SERVER_UNKNOWN_FOUND
+    };
+
+    server_type getServerType() { return type; }
+    std::string& getServerVersion() { return version; }
+
+    ServerDetect(drizzle_con_st *connection) :
+      type(SERVER_UNKNOWN_FOUND),
+      version("")
+    {
+      boost::match_flag_type flags = boost::match_default;
+
+      boost::regex mysql_regex("(5\\.[0-9]+\\.[0-9]+)");
+      boost::regex drizzle_regex("(20[0-9]{2}\\.(0[1-9]|1[012])\\.[0-9]+)");
+
+      version= drizzle_con_server_version(connection);
+
+      if (regex_search(version, mysql_regex, flags))
+        type= SERVER_MYSQL_FOUND;
+      else if (regex_search(version, drizzle_regex, flags))
+        type= SERVER_DRIZZLE_FOUND;
+      else
+        type= SERVER_UNKNOWN_FOUND;
+    }
+
+  private:
+    server_type type;
+    std::string version;
+};
+
+#endif /* CLIENT_SERVER_DETECT_H */

=== modified file 'drizzled/field/boolean.cc'
--- drizzled/field/boolean.cc	2011-02-19 01:04:19 +0000
+++ drizzled/field/boolean.cc	2011-02-21 20:14:39 +0000
@@ -60,6 +60,8 @@
         field_name_arg),
   ansi_display(ansi_display_arg)
   {
+    if (ansi_display)
+      flags|= UNSIGNED_FLAG;
   }
 
 int Boolean::cmp(const unsigned char *a, const unsigned char *b)

=== modified file 'libdrizzle/column.c'
--- libdrizzle/column.c	2010-12-23 18:47:57 +0000
+++ libdrizzle/column.c	2011-02-21 18:47:31 +0000
@@ -65,7 +65,7 @@
 static drizzle_column_type_drizzle_t _column_type_drizzle_map_from[]=
 {
  DRIZZLE_COLUMN_TYPE_DRIZZLE_MAX, /* 0 */
- DRIZZLE_COLUMN_TYPE_DRIZZLE_TINY,
+ DRIZZLE_COLUMN_TYPE_DRIZZLE_BOOLEAN,
  DRIZZLE_COLUMN_TYPE_DRIZZLE_MAX,
  DRIZZLE_COLUMN_TYPE_DRIZZLE_LONG,
  DRIZZLE_COLUMN_TYPE_DRIZZLE_MAX,

=== modified file 'libdrizzle/constants.h'
--- libdrizzle/constants.h	2010-12-19 16:20:13 +0000
+++ libdrizzle/constants.h	2011-02-21 18:47:31 +0000
@@ -391,7 +391,11 @@
   DRIZZLE_COLUMN_TYPE_DRIZZLE_NEWDECIMAL,
   DRIZZLE_COLUMN_TYPE_DRIZZLE_ENUM,
   DRIZZLE_COLUMN_TYPE_DRIZZLE_BLOB,
-  DRIZZLE_COLUMN_TYPE_DRIZZLE_MAX=DRIZZLE_COLUMN_TYPE_DRIZZLE_BLOB
+  DRIZZLE_COLUMN_TYPE_DRIZZLE_TIME,
+  DRIZZLE_COLUMN_TYPE_DRIZZLE_BOOLEAN,
+  DRIZZLE_COLUMN_TYPE_DRIZZLE_UUID,
+  DRIZZLE_COLUMN_TYPE_DRIZZLE_MICROTIME,
+  DRIZZLE_COLUMN_TYPE_DRIZZLE_MAX=DRIZZLE_COLUMN_TYPE_DRIZZLE_MICROTIME
 } drizzle_column_type_drizzle_t;
 
 /**

=== modified file 'plugin/mysql_protocol/mysql_protocol.cc'
--- plugin/mysql_protocol/mysql_protocol.cc	2011-02-20 00:09:56 +0000
+++ plugin/mysql_protocol/mysql_protocol.cc	2011-02-20 10:23:17 +0000
@@ -35,6 +35,8 @@
 
 #include <drizzled/identifier.h>
 
+#include <libdrizzle/constants.h>
+
 #define PROTOCOL_VERSION 10
 
 namespace po= boost::program_options;
@@ -558,7 +560,7 @@
         break;
 
       case DRIZZLE_TYPE_BOOLEAN:
-        pos[6]= 15;
+        pos[6]= DRIZZLE_COLUMN_TYPE_TINY;
         break;
 
       case DRIZZLE_TYPE_DECIMAL:
@@ -609,6 +611,11 @@
 {
   if (from->is_null())
     return store();
+  if (from->type() == DRIZZLE_TYPE_BOOLEAN)
+  {
+    return store(from->val_int());
+  }
+
   char buff[MAX_FIELD_WIDTH];
   String str(buff,sizeof(buff), &my_charset_bin);
 

=== modified file 'po/Makefile.in.in'
--- po/Makefile.in.in	2011-02-14 20:32:29 +0000
+++ po/Makefile.in.in	2011-02-22 00:30:21 +0000
@@ -145,7 +145,7 @@
 check: all $(GETTEXT_PACKAGE).pot
 	rm -f missing notexist
 	srcdir=$(srcdir) $(INTLTOOL_UPDATE) -m
-	if [ -r missing -o -r notexist -a "x${INTLTOOL_WARNINGS}" = "xyes"]; then \
+	if [ -r missing -o -r notexist -a "x${INTLTOOL_WARNINGS}" = "xyes" ]; then \
 	  exit 1; \
 	fi
 

=== modified file 'tests/r/show_check.result'
--- tests/r/show_check.result	2011-02-04 09:04:08 +0000
+++ tests/r/show_check.result	2011-02-21 20:14:39 +0000
@@ -27,7 +27,7 @@
 show index from t1;
 Catalog	Database	Table	Table_alias	Column	Column_alias	Type	Length	Max length	Is_null	Flags	Decimals	Charsetnr
 def	data_dictionary	show_indexes	SHOW_INDEXES	Table	Table	8	1024	2	N	4097	0	45
-def	data_dictionary	show_indexes	SHOW_INDEXES	Unique	Unique	8	1	3	N	4097	0	63
+def	data_dictionary	show_indexes	SHOW_INDEXES	Unique	Unique	13	1	1	N	36897	0	63
 def	data_dictionary	show_indexes	SHOW_INDEXES	Key_name	Key_name	8	1024	7	N	4097	0	45
 def	data_dictionary	show_indexes	SHOW_INDEXES	Seq_in_index	Seq_in_index	5	21	1	N	36865	0	63
 def	data_dictionary	show_indexes	SHOW_INDEXES	Column_name	Column_name	8	1024	1	N	4097	0	45
@@ -447,7 +447,7 @@
 show index from t1;
 Catalog	Database	Table	Table_alias	Column	Column_alias	Type	Length	Max length	Is_null	Flags	Decimals	Charsetnr
 def	data_dictionary	show_indexes	SHOW_INDEXES	Table	Table	8	1024	2	N	4097	0	45
-def	data_dictionary	show_indexes	SHOW_INDEXES	Unique	Unique	8	1	3	N	4097	0	63
+def	data_dictionary	show_indexes	SHOW_INDEXES	Unique	Unique	13	1	1	N	36897	0	63
 def	data_dictionary	show_indexes	SHOW_INDEXES	Key_name	Key_name	8	1024	7	N	4097	0	45
 def	data_dictionary	show_indexes	SHOW_INDEXES	Seq_in_index	Seq_in_index	5	21	1	N	36865	0	63
 def	data_dictionary	show_indexes	SHOW_INDEXES	Column_name	Column_name	8	1024	6	N	4097	0	45

